@@ -1,7 +1,7 @@
 from zigzag.classes.stages import *
 
 
-def get_hardware_performance(onnx_model, accelerator, mapping=None, dump_filename_pattern="outputs/{datetime}.json", pickle_filename="outputs/list_of_cmes.pickle"):
+def get_hardware_performance(onnx_model, accelerator, mapping=None, opt='latency', dump_filename_pattern="outputs/{datetime}.json", pickle_filename="outputs/list_of_cmes.pickle"):
     
     # Initialize the logger
     import logging as _logging
@@ -11,16 +11,25 @@ def get_hardware_performance(onnx_model, accelerator, mapping=None, dump_filenam
     _logging.basicConfig(level=_logging_level,
                         format=_logging_format)
 
+    # Sanity check on the optimization criterion
+    if opt == 'energy':
+        opt_stage = MinimalEnergyStage
+    elif opt == 'latency':
+        opt_stage = MinimalLatencyStage
+    else:
+        raise NotImplementedError("Optimization criterion 'opt' should be either 'energy' or 'latency'.")
+
     mainstage = MainStage([  # Initialize the MainStage as entry point
         ONNXModelParserStage,  # Parse the ONNX Model into the workload
         AcceleratorParserStage,  # Parse the accelerator module/passthrough given accelerator
-        SimpleSaveStage,  # Save the summed CME to a json
+        SimpleSaveStage,  # Save the summed CME energy and latency to a json
         PickleSaveStage,  # Save all received CMEs in a list to a pickle file
         SumStage,  # Sum up the received best CME across all layers of he workload
         WorkloadStage,  # Iterate through the different layers in the workload
-        MinimalLatencyStage,  # Reduce all CMEs, returning minimal latency one
+        CompleteSaveStage,  # Save each processed layer to a json
+        opt_stage,  # Reduce all CMEs, returning minimal energy/latency one
         SpatialMappingGeneratorStage,  # Generate multiple spatial mappings (SM)
-        MinimalLatencyStage,  # Reduce all CMEs, returning minimal latency one
+        opt_stage,  # Reduce all CMEs, returning minimal energy/latency one
         LomaStage,  # Generate multiple temporal mappings (TM)
         CostModelStage  # Evaluate generated SM and TM through cost model
     ],
@@ -39,4 +48,4 @@ def get_hardware_performance(onnx_model, accelerator, mapping=None, dump_filenam
     # Get CME from answer
     cme = answers[0][0]
 
-    return cme.energy_total, cme.latency_total2
\ No newline at end of file
+    return cme.energy_total, cme.latency_total2, cme
\ No newline at end of file
